"""Alternatives to Python's built-in containers"""
from .deepdefaultdict import defaultdict, deepdefaultdict
from .functions import (
    identity,
    prod,
)
from .lazylist import lazy_content, LazyList
from .flatstr import FlatStr
from .singleton import Singleton
